==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/rdrtprofile/siterole/customcase/custom/DefaultExportRt.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.rdrtprofile.siterole.customcase.custom;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.extendedcommunity.ExtendedCommunity;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of exportRt.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultExportRt extends InnerModelObject 
        implements ExportRt, MultiInstanceObject<ExportRtKeys> {
    protected String exrtId;
    protected BitSet valueLeafFlags = new BitSet();
    protected ExtendedCommunity extendedCommunity;

    @Override
    public String exrtId() {
        return exrtId;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public ExtendedCommunity extendedCommunity() {
        return extendedCommunity;
    }

    @Override
    public void exrtId(String exrtId) {
        valueLeafFlags.set(LeafIdentifier.EXRTID.getLeafIndex());
        this.exrtId = exrtId;
    }

    @Override
    public void extendedCommunity(ExtendedCommunity extendedCommunity) {
        this.extendedCommunity = extendedCommunity;
    }

    @Override
    public int hashCode() {
        return Objects.hash(exrtId, valueLeafFlags, extendedCommunity);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultExportRt) {
            DefaultExportRt other = (DefaultExportRt) obj;
            return
                Objects.equals(exrtId, other.exrtId) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.equals(extendedCommunity, other.extendedCommunity);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("exrtId=" + exrtId)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("extendedCommunity=" + extendedCommunity)
            .toString();
    }


    /**
     * Creates an instance of defaultExportRt.
     */
    public DefaultExportRt() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/rdrtprofile/siterole/customcase/custom/DefaultExportRt.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.rdrtprofile.siterole.customcase.custom;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.extendedcommunity.ExtendedCommunity;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of exportRt.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultExportRt extends InnerModelObject 
        implements ExportRt, MultiInstanceObject<ExportRtKeys> {
    protected String exrtId;
    protected BitSet valueLeafFlags = new BitSet();
    protected ExtendedCommunity extendedCommunity;

    @Override
    public String exrtId() {
        return exrtId;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public ExtendedCommunity extendedCommunity() {
        return extendedCommunity;
    }

    @Override
    public void exrtId(String exrtId) {
        valueLeafFlags.set(LeafIdentifier.EXRTID.getLeafIndex());
        this.exrtId = exrtId;
    }

    @Override
    public void extendedCommunity(ExtendedCommunity extendedCommunity) {
        this.extendedCommunity = extendedCommunity;
    }

    @Override
    public int hashCode() {
        return Objects.hash(exrtId, valueLeafFlags, extendedCommunity);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultExportRt) {
            DefaultExportRt other = (DefaultExportRt) obj;
            return
                Objects.deepEquals(exrtId, other.exrtId) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.deepEquals(extendedCommunity, other.extendedCommunity);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("exrtId=" + exrtId)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("extendedCommunity=" + extendedCommunity)
            .toString();
    }


    /**
     * Creates an instance of defaultExportRt.
     */
    public DefaultExportRt() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
